@@ -39,7 +39,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    Q_DEBUG("Using qgvdial version 0.3.953");
+    Q_DEBUG("Using qgvdial version 0.3.956");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -162,8 +162,8 @@ MainWindow::onSigSendLogs()
         return;
     }
 
-    NwReqTracker *tracker = new NwReqTracker(reply, NULL, NW_REPLY_TIMEOUT,
-                                             true, this);
+    NwReqTracker *tracker = new NwReqTracker(reply, *nwMgr, NULL,
+                                             NW_REPLY_TIMEOUT, true, this);
     connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
             this, SLOT(onGetLogLocation(bool,QByteArray,QNetworkReply*,void*)));
 }//MainWindow::onSigSendLogs
@@ -219,7 +219,7 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
         QDomElement appVerTag = doc.createElement("Version");
         paramsTag.appendChild(appVerTag);
 
-        QDomText appVerText = doc.createTextNode("0.3.953");
+        QDomText appVerText = doc.createTextNode("0.3.956");
         appVerTag.appendChild(appVerText);
 
         QDomElement osVerTag = doc.createElement("OsVer");
@@ -254,8 +254,8 @@ MainWindow::onGetLogLocation(bool success, const QByteArray &response,
             break;
         }
 
-        NwReqTracker *tracker = new NwReqTracker(reply, token, NW_REPLY_TIMEOUT,
-                                                 true, this);
+        NwReqTracker *tracker = new NwReqTracker(reply, *nwMgr, token,
+                                                 NW_REPLY_TIMEOUT, true, this);
         connect(tracker, SIGNAL(sigDone(bool,QByteArray,QNetworkReply*,void*)),
                 this, SLOT(onLogPosted(bool,QByteArray,QNetworkReply*,void*)));
     } while (0); // End cleanup block (not a loop)
@@ -287,7 +287,7 @@ MainWindow::onLogPosted(bool success, const QByteArray &response,
         QDateTime dt = token->inParams["date"].toDateTime();
         QString body = QString("Logs captured at %1 \n")
                                 .arg (dt.toUTC ().toString (Qt::ISODate));
-        body += "qgvdial version = 0.3.953 \n";
+        body += "qgvdial version = 0.3.956 \n";
         body += QString("OS: %1 \n").arg(osd.getOSDetails());
         body += QString("Logs are in %1 \n").arg(strReply);
         url.addQueryItem ("body", body);
